phonesrv_plat/phone_client_ussd_internal_api/inc/cphcltussdint.h
changeset 51 12bc758d6a02
parent 33 8d5d7fcf9b59
--- a/phonesrv_plat/phone_client_ussd_internal_api/inc/cphcltussdint.h	Fri Sep 17 17:09:13 2010 +0300
+++ b/phonesrv_plat/phone_client_ussd_internal_api/inc/cphcltussdint.h	Mon Oct 04 15:57:13 2010 +0300
@@ -91,8 +91,8 @@
         
      protected:
 
-        // CUssdComms can call the protected functions mentioned above.
-        friend class CUssdComms;
+        // UssdComms can call the protected functions mentioned above.
+        friend class UssdComms;
         
     };